pub struct SecurityReportRow<T> {
pub folder_name: String,
pub folder_id: VaultId,
pub secret_id: SecretId,
pub field_id: Option<SecretId>,
pub score: Score,
pub guesses: u64,
pub guesses_log10: f64,
pub database_check: T,
}Expand description
Row for security report output.
Fields
folder_name: StringFolder name.
folder_id: VaultIdFolder identifier.
secret_id: SecretIdSecret identifier.
field_id: Option<SecretId>Custom field identifier.
score: ScoreThe entropy score.
guesses: u64The estimated number of guesses needed to crack the password.
guesses_log10: f64The order of magnitude of guesses.
database_check: TResult of a database check.
Implementations
Sourceimpl SecurityReportRow<bool>
impl SecurityReportRow<bool>
Sourcepub fn is_secure(&self) -> bool
pub fn is_secure(&self) -> bool
Determine if this row is deemed to be secure.
A report is deemed to be secure when the entropy score is greater than or equal to 3 and the password hash has not been detected as appearing in a database of breached passwords.
Sourcepub fn is_insecure(&self) -> bool
pub fn is_insecure(&self) -> bool
Determine if this row is deemed to be insecure.