pub struct SecurityReportOptions<T, H, F>{
pub excludes: Vec<VaultId>,
pub database_handler: Option<H>,
pub target: Option<SecurityReportTarget>,
}Expand description
Options for security report generation.
Fields
excludes: Vec<VaultId>Exclude these folders from report generation.
database_handler: Option<H>Database handler that can check for breaches based on the password hashes (SHA-1).
The handler is passed a list of passwords hashes
and must return a list of T the same length as
the input.
target: Option<SecurityReportTarget>Target for report generation.
This is useful when providing a UI to resolve security report issues and changes have been made; the caller can generate a new report for the changed item and decide if the item is now deemed safe.
When a target is given excludes are ignored.